# AnalysisResultResponseResultDebdependencies

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**depends** | [**DebDependencyItem**](DebDependencyItem.md) |  |
**epoch** | **str** | Debian package epoch |
**name** | **str** | Debian package name |
**pre_depends** | [**DebDependencyItem**](DebDependencyItem.md) |  |
**replaces** | [**DebDependencyItem**](DebDependencyItem.md) |  |
**version** | **str** | Debian package version |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

